package com.example.demo.supply.Product;

import jakarta.validation.Valid;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

@Controller
@RequestMapping("/product")
public class ProductMvcController {
    private final ProductService productService;

    public ProductMvcController(ProductService productService){ this.productService = productService;}

    @GetMapping
    public String getProducts(Model model) {
        model.addAttribute("products",
                productService.findAllProducts().stream().map(ProductDto::new).toList());
        return "product";
    }

    @GetMapping(value = {"/edit", "/edit/{id}"})
    public String editProduct(@PathVariable(required = false) Long id,
                              Model model) {
        if (id == null || id <= 0) {
            model.addAttribute("productDto", new ProductDto());
        } else {
            model.addAttribute("productId", id);
            model.addAttribute("productDto", new ProductDto(productService.findProduct(id)));
        }
        return "product-edit";
    }

    @PostMapping(value = {"", "/{id}"})
    public String saveProduct(@PathVariable(required = false) Long id,
                              @ModelAttribute @Valid ProductDto productDto,
                              BindingResult bindingResult,
                              Model model) {
        if (bindingResult.hasErrors()) {
            model.addAttribute("errors", bindingResult.getAllErrors());
            return "product-edit";
        }
        if (id == null || id <= 0) {
            productService.addProduct(productDto.getName(), productDto.getCost());
        } else {
            productService.updateProduct(id, productDto.getName(), productDto.getCost());
        }
        return "redirect:/product";
    }

    @PostMapping("/delete/{id}")
    public String deleteProduct(@PathVariable Long id) {
        productService.deleteProduct(id);
        return "redirect:/product";
    }
}
